@@ -14,35 +14,30 @@ CONFIG = {
     "log_file": {
         "dyne": "__cli__",
         "default": f"{os.path.splitext(os.path.split(sys.argv[0])[1])[0]}.log",
-        "os": "POP_LOG_FILE",
         "help": "The location of the log file",
         "group": "Logging Options",
     },
     "log_level": {
         "dyne": "__cli__",
         "default": "warning",
-        "os": "POP_LOG_LEVEL",
         "help": "Set the log level, either quiet, info, warning, or error",
         "group": "Logging Options",
     },
     "log_fmt_logfile": {
         "dyne": "__cli__",
         "default": "%(asctime)s,%(msecs)03d [%(name)-17s][%(levelname)-8s] %(message)s",
-        "os": "POP_LOGFILE_FORMAT",
         "help": "The format to be given to log file messages",
         "group": "Logging Options",
     },
     "log_fmt_console": {
         "dyne": "__cli__",
         "default": "[%(levelname)-8s] %(message)s",
-        "os": "POP_LOG_FORMAT_CONSOLE",
         "help": "The log formatting used in the console",
         "group": "Logging Options",
     },
     "log_datefmt": {
         "dyne": "__cli__",
         "default": "%H:%M:%S",
-        "os": "POP_LOG_DATE_FORMAT",
         "help": "The date format to display in the logs",
         "group": "Logging Options",
     },
