@@ -4,8 +4,8 @@ Find the conf.py files specified in sources
 # Import python libs
 import importlib
 import copy
-import os
-import dict_tools
+import os.path
+import dict_tools.update
 
 
 def _load_pyimp(hub, imp):
@@ -80,6 +80,7 @@ def load(hub, sources, dyne_names, cli):
                         new_dyne = cli
                     if new_dyne:
                         val["source"] = new_dyne
+                    if new_dyne == cli:
                         subcmd_draw[key] = val
                 dict_tools.update.update(raw[cli]["SUBCOMMANDS"], subcmd_draw)
     return raw
